"""
    safeenergy(Zₚ,Aₚ,Zₜ,Aₜ)

Estimate the maximum safe bombarding energy (MeV) for Coulomb excitation.

Based on Cline's estimate for a distance of 5 fm.

# Arguments
- `Zₚ::Int64`: proton number of the projectile.
- `Aₚ::Int64`: mass of the projectile.
- `Zₜ::Int64`: proton number of the target.
- `Aₜ::Int64`: mass of the target.

# Examples
```jldoctest
julia> safeenergy(26,58,79,197) # 58Fe on 197Au
223.73735985118967
```

"""
function safeenergy(Zₚ,Aₚ,Zₜ,Aₜ)
	return 1.44*(Aₚ+Aₜ)*Zₚ*Zₜ/(5+1.25*(cbrt(Aₚ)+cbrt(Aₜ)))/Aₜ
end
