"""
    cosanglebetween(θ₁,ϕ₁,θ₂,ϕ₂)

The cosine of the angle between two detectors in spherical coordinates in degrees.

"""
function cosanglebetween(θ₁,ϕ₁,θ₂,ϕ₂)
        return cosd(θ₁)*cosd(θ₂) + cosd(ϕ₁-ϕ₂)*sind(θ₁)*sind(θ₂)
end

"""
    dopplershift(β,cosθ)

Gives the Doppler-shift factor.

# Arguments
- `β::Float64`: The speed of the particle v/c.
- `cosθ::Float64`: The cosine of the detection angle.

"""
function dopplershift(β,cosθ)
        return (1 - β*cosθ)/sqrt(1 - β^2)
end

"""
    dopplerspeed(Eᵧ,Eₘ,cosθ)

Calculate the particle speed v/c from a Doppler-shifted energy.

# Arguments
- `Eᵧ::Float64`: The true energy.
- `Eₘ::Float64`: The measured energy.
- `cosθ::Float64`: The cosine of the detection angle.

"""
function dopplerspeed(Eᵧ,Eₘ,cosθ)
    return (cosθ*(Eₘ^2) + sign(Eᵧ-Eₘ)sqrt((cosθ^2 - 1) * Eₘ^2 * Eᵧ^2 + Eᵧ^4)) / (cosθ^2 * Eₘ^2 + Eᵧ^2)
end
